clear
clear matrix
set more off

**set location of base_directory below:
local base_dir "D:\KPR_Appendix_Feb2017"

local in_dir "`base_dir'\Data"
local out_dir "`base_dir'\Output"
local temp_dir "`base_dir'\temp"

cd "`out_dir'"

**load data
insheet using  "`in_dir'\GTAPData_HS02.csv", comma clear names

rename tradevaluein1000usd value
gen importer_iso = partneriso3
gen exporter_iso = reporteriso3


**replace country alpha codes with numeric codes
gen exporter = 36 if exporter_iso == "AUS"
gen importer = 36 if importer_iso == "AUS"
replace exporter = 842 if exporter_iso == "USA"
replace importer = 842 if importer_iso == "USA"
replace exporter = 156 if exporter_iso == "CHN"
replace importer = 156 if importer_iso == "CHN"
replace exporter = 152 if exporter_iso == "CHL"
replace importer = 152 if importer_iso == "CHL"
replace exporter = 554 if exporter_iso == "NZL"
replace importer = 554 if importer_iso == "NZL"
drop if importer == exporter

rename productcode code

keep year importer exporter code value 
order exporter importer code year value

**gen pair
gen pair = string(exporter,"%03.0f") + "-" + string(importer,"%03.0f") + "-" + string(code,"%06.0f")

fillin pair year
replace value=0 if value==.
replace exporter = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9]"))
replace importer = real(regexs(1)) if(regexm(pair,".([0-9][0-9][0-9])"))
replace code = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9][0-9][0-9][0-9]"))
drop _fillin

reshape wide value, i(pair) j(year)

gen pre_val = value2004
gen post_val = value2015

egen pre_val_avg = rowmean(value2002 value2003 value2004)


save "`temp_dir'\temp", replace

collapse (sum) pre_val, by(importer exporter)
rename pre_val pre_total

merge 1:m importer exporter using "`temp_dir'\temp"
drop _merge
save "`temp_dir'\temp", replace

sort importer exporter pre_val_avg

drop if pre_total==0
gen freq = pre_val/pre_total

by importer exporter, sort: gen cum_freq = sum(freq)

gen least=1 if cum_freq<0.10
replace least= (0.1-cum_freq[_n-1])*pre_total /pre_val if cum_freq >0.1 & cum_freq[_n-1]<0.1
replace least=0 if least==.


rename code hs2002

keep importer exporter pre_val pre_val_avg post_val least hs2002

gen least_val_pre = least*pre_val
gen least_val_post = least*post_val

gen notleast = abs(1-least)

gen notleast_val_pre = notleast*pre_val
gen notleast_val_post = notleast*post_val


save "`temp_dir'\temp", replace


**
** concord the trade data
**
insheet using "`in_dir'\HS_GTAP_Concordance.csv", comma clear names
drop v*
rename hs hs2002

destring hs2002, replace force
drop if hs2002 == .

collapse (first) gtap, by(hs2002)

merge 1:m hs2002 using "`temp_dir'\temp"
**merge=1 means no trade in that good in data, merge=2 means code doesn't show up in concordance table (merge=2 doesn't happen)
drop if _merge == 1
drop _merge


collapse (sum) pre_val pre_val_avg post_val least_val_* notleast_val_* least notleast, by(importer exporter gtap)

save "`temp_dir'\temp", replace

****
**Merge in GDPS
****

insheet using "`in_dir'\WDI_GDPs.csv", clear comma names

reshape wide gdp, i(countrycode) j(year)
rename gdp2002 GDP_pre
rename gdp2015 GDP_post
keep countrycode GDP_*
rename countrycode exporter


merge 1:m exporter using "`temp_dir'\temp"
drop _merge
save "`temp_dir'\temp", replace

****
**gen growth and LTP
****
gen perleast = least_val_pre/(least_val_pre+notleast_val_pre)
gen growth = 100*((post_val/GDP_post)/(pre_val/GDP_pre)-1)

gen gtap_pair = string(exporter,"%03.0f") + "-" + string(importer,"%03.0f") + "-" + string(gtap,"%02.0f")

save "`temp_dir'\temp", replace

*****
**Merge in GTAP results
*****

merge 1:1 gtap_pair using "`in_dir'\GTAP_Results"
**merge == 1 means no GTAP predictions, merge == 2 means no trade data available
drop if _merge == 1 | _merge == 2
drop _merge


**label data
label define country 36 "Australia" 842 "UnitedStates" 156 "China" 152 "Chile" 554 "NewZealand" 0 "World"
label define ctry 36 "Aus" 842 "USA" 156 "Chn" 152 "Chl" 554 "Nzl" 0 "World"
label values importer ctry
label values exporter ctry

label var importer Importer
label var exporter Exporter


****
**Generate Results
****
drop if sim_growth == .
drop if pre_val == 0 | pre_val == . | post_val == 0 | post_val == .

**drop oil for US Exports to Chile -- Fracking
**drop beef for US imports from Australia -- Mad cow disease
drop if gtap == 32 & exporter == 842 & importer == 152
drop if gtap == 19 & exporter == 36 & importer == 842

bysort exporter importer: egen pre_tot = total(pre_val)
bysort exporter importer: egen post_tot = total(post_val)

gen weight = (((pre_val/pre_tot)+(post_val/post_tot))/2)

***INSTALL PACKAGE ESTOUT IF NOT ALREADY INSTALLED
**ssc install estout
***

**Produce Table A.9 of Robustness Appendix (different base years)
eststo clear
bysort exporter importer: eststo: quietly estpost correlate growth sim_growth perleast [aweight = weight]
esttab est* using "`out_dir'\KPR2017_TableA9.txt", label title(GTAP_LTP_Results) nodepvar noobs b(2) nostar not replace


