clear
clear matrix
set more off

**edit location of base_directory below:
local base_dir "D:\KPR_Appendix_Feb2017"

local in_dir "`base_dir'\Data"
local out_dir "`base_dir'\Output"
local temp_dir "`base_dir'\temp"

cd "`out_dir'"

**load data
insheet using "`in_dir'\NAFTAData_HS92.csv", comma clear names

rename tradevaluein1000usd value
gen importer_iso = partneriso3
gen exporter_iso = reporteriso3

**replace country alpha codes with numeric codes
gen exporter = 124 if exporter_iso == "CAN"
gen importer = 124 if importer_iso == "CAN"
replace exporter = 842 if exporter_iso == "USA"
replace importer = 842 if importer_iso == "USA"
replace exporter = 484 if exporter_iso == "MEX"
replace importer = 484 if importer_iso == "MEX"
drop if importer == exporter

rename productcode code

keep year importer exporter code value 
order exporter importer code year value

**drop the goods NEC
drop if code == "9999AA"
**replace strings with numeric for HS1992 codes
destring code, replace

**gen pair
gen pair = string(exporter,"%03.0f") + "-" + string(importer,"%03.0f") + "-" + string(code,"%06.0f")

fillin pair year
replace value=0 if value==.
replace exporter = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9]"))
replace importer = real(regexs(1)) if(regexm(pair,".([0-9][0-9][0-9])"))
replace code = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9][0-9][0-9][0-9]"))
drop _fillin

reshape wide value, i(pair) j(year)

gen pre_val = value1991
gen post_val = value2006

egen pre_val_avg = rowmean(value1991 value1992 value1993)

save "`temp_dir'\temp", replace

collapse (sum) pre_val, by(importer exporter)
rename pre_val pre_total

merge 1:m importer exporter using "`temp_dir'\temp"
drop _merge
save "`temp_dir'\temp", replace

sort importer exporter pre_val_avg

drop if pre_total==0
gen freq = pre_val/pre_total

by importer exporter, sort: gen cum_freq = sum(freq)

gen least=1 if cum_freq<0.10
replace least= (0.1-cum_freq[_n-1])*pre_total /pre_val if cum_freq >0.1 & cum_freq[_n-1]<0.1
replace least=0 if least==.

rename code hs1992

keep importer exporter pre_val pre_val_avg post_val least hs1992

gen least_val_pre = least*pre_val
gen least_val_post = least*post_val

gen notleast = abs(1-least)

gen notleast_val_pre = notleast*pre_val
gen notleast_val_post = notleast*post_val


save "`temp_dir'\temp", replace

**
** concord the GDP data
**
insheet using "`in_dir'\NAFTA_GDPs.csv", comma clear names

reshape wide gdp, i(countrycode) j(year)
rename gdp1991 GDP_pre
rename gdp2006 GDP_post
keep countrycode GDP_*
rename countrycode exporter

merge 1:m exporter using "`temp_dir'\temp"
drop _merge
save "`temp_dir'\temp", replace

**
** concord the trade data
**
insheet using "`in_dir'\concordance_H0_to_I3.csv", comma clear names
gen isic3_2digit = floor(isicrevision3productcode/100)
rename hs198892productcode hs1992

**collapse (first) gtap, by(hs2002)
keep hs1992 isic3_2digit
append using "`in_dir'\concordance_H0_to_I3_missing.dta"

merge 1:m hs1992 using "`temp_dir'\temp"
**merge=1 means no trade in that good in data, merge=2 means code doesn't show up in concordance table (merge=2 doesn't happen)
drop if _merge == 1
drop _merge

save "`temp_dir'\temp", replace
**now concord to Caliendo_Parro Industries
insheet using "`in_dir'\CP_concordance.csv", comma clear names

rename isic_code isic3_2digit
keep isic3_2digit cp_industry_code

merge 1:m isic3_2digit using "`temp_dir'\temp"
**merge=1 means no trade in that good in data, merge=2 means code doesn't show up in concordance table (merge=2 doesn't happen)
drop if _merge == 1
drop _merge

**collapse by Caliendo_Parro Industries
collapse (sum) pre_val pre_val_avg post_val least_val_* notleast_val_* least notleast (first) GDP_pre GDP_post, by(importer exporter cp_industry_code)


gen perleast = least_val_pre/(least_val_pre+notleast_val_pre)
gen growth = 100*(log(post_val/GDP_post)-log(pre_val/GDP_pre))

gen CP_pair = string(exporter,"%03.0f") + "-" + string(importer,"%03.0f") + "-" + string(cp_industry_code,"%02.0f")

save "`temp_dir'\temp", replace

***
**Merge in C-P Results
***
merge 1:1 CP_pair using "`in_dir'\CP_Results"
**some of the industries CP consider non-traded even though they have trade
drop if _merge == 2
drop _merge


**label data
label define country 124 "Canada" 484 "Mexico" 842 "UnitedStates" 0 "World"
label define ctry 124 "Can" 484 "Mex" 842 "USA" 0 "World"
label values importer country
label values exporter country

label var importer Importer
label var exporter Exporter

drop CP_pair

save "`out_dir'\CP_LTP_results", replace


***
use "`out_dir'\CP_LTP_results", replace
***

**drop industries with no trade or CP prediction, so compute accuracy only for same set of industries
drop if sim_growth == .
drop if pre_val == 0 | pre_val == . | post_val == 0 | post_val == .

bysort exporter importer: egen pre_tot = total(pre_val)
bysort exporter importer: egen post_tot = total(post_val)

gen weight = (((pre_val/pre_tot)+(post_val/post_tot))/2)

***INSTALL PACKAGE ESTOUT IF NOT ALREADY INSTALLED
**ssc install estout
***

**Level predictions for LTP methodology, coefficients are from KPR2017_Level_Coefficients.xlsx
gen predgrowth = 4.42007223438387 + 17.8692575429687* perleast if importer == 842 & exporter == 124
replace predgrowth = 18.6798526953896 + 75.5180189323679* perleast if importer == 124 & exporter == 484
replace predgrowth = 15.4153280742257 + 62.3203542523307* perleast if importer == 842 & exporter == 484
replace predgrowth = 7.84118839967614 + 31.6999830606348* perleast if importer == 124 & exporter == 842
replace predgrowth = 41.0759086358934 + 166.059727376502* perleast if importer == 484 & exporter == 124
replace predgrowth = 40.557356471106 + 163.96334937843* perleast if importer == 484 & exporter == 842


**compute accuracy (% diff) of level predictions
gen abs_accuracy_NAFTA =  abs(100*(growth - sim_growth)/sim_growth)
gen abs_accuracy_LTP =  abs(100*(growth - predgrowth)/predgrowth)


**Produce Table 2 of Paper
eststo clear
bysort exporter importer: eststo: quietly estpost correlate growth sim_growth sim_growth_oN sim_growth_oN_noIO perleast [aweight = weight]
esttab est* using "`out_dir'\KPR2017_Table2.txt", label title(NAFTA_CP_LTP_Results) nodepvar noobs b(2) nostar not replace

**For paper text only: regression to find relative growth rates of LTP and non-LTP for Mexican exports to Canada
**add estimated coefficient to _cons to get LTP growth rate, _cons is non-LTP growth rate
reg growth perleast [aweight = pre_val] if exporter == 484 & importer == 124

**Produce Table A.6 of Robustness Appendix (unweighted correlations)
eststo clear
bysort exporter importer: eststo: quietly estpost correlate growth sim_growth sim_growth_oN sim_growth_oN_noIO perleast
esttab est* using "`out_dir'\KPR2017_TableA6.txt", label title(NAFTA_CP_LTP_Results) nodepvar noobs b(2) nostar not replace

**Produce Table A.7 of Robustness Appendix (unweighted correlations, exclude little traded industries)
eststo clear
bysort exporter importer: eststo: quietly estpost correlate growth sim_growth sim_growth_oN sim_growth_oN_noIO perleast if weight > 0.01
esttab est* using "`out_dir'\KPR2017_TableA7.txt", label title(NAFTA_CP_LTP_Results) nodepvar noobs b(2) nostar not replace

**Produce Table A.8 of Robustness Appendix (unweighted correlations, exclude little traded industries and industries with extreme growth)
eststo clear
bysort exporter importer: eststo: quietly estpost correlate growth sim_growth sim_growth_oN sim_growth_oN_noIO perleast if weight > 0.01 & growth > -100 & growth < 200
esttab est* using "`out_dir'\KPR2017_TableA8.txt", label title(NAFTA_CP_LTP_Results) nodepvar noobs b(2) nostar not replace

**change from log differences to percent changes
replace growth = 100*(exp(growth/100)-1)
replace sim_growth = 100*(exp(sim_growth/100)-1)
replace sim_growth_oN = 100*(exp(sim_growth_oN/100)-1)
replace sim_growth_oN_noIO = 100*(exp(sim_growth_oN_noIO/100)-1)

**Produce Table A.2 of Robustness Appendix (percent changes)
eststo clear
bysort exporter importer: eststo: quietly estpost correlate growth sim_growth sim_growth_oN sim_growth_oN_noIO perleast [aweight = weight]
esttab est* using "`out_dir'\KPR2017_TableA2.txt", label title(NAFTA_CP_LTP_Results) nodepvar noobs b(2) nostar not replace

**Drop petroleum exports from US to Mexico
drop if exporter == 842 & importer == 484 & cp_industry_code == 07

**Produce Table A.3 of Robustness Appendix (percent changes, exclude petroleum exports)
eststo clear
bysort exporter importer: eststo: quietly estpost correlate growth sim_growth sim_growth_oN sim_growth_oN_noIO perleast [aweight = weight]
esttab est* using "`out_dir'\KPR2017_TableA3.txt", label title(NAFTA_CP_LTP_Results) nodepvar noobs b(2) nostar not replace

**Produce Table A.12 of Robustness Appendix (mean absolute percentage difference)
collapse (mean) abs_* [aweight = weight], by(importer exporter)
keep exporter importer abs_accuracy_*
order exporter importer abs_accuracy_*
format abs_accuracy_* %9.1f
sort exporter importer
outsheet using "`out_dir'\KPR2017_TableA12.txt", names replace
