%%How to generate testable predictions for the CP methodology

%%%%%%%%
%%Step 1: Run matlab file from Caliendo-Parro dataappendix to compute changes in bilateral trade shares
%%Data appendix is available on the author's website: http://faculty.som.yale.edu/lorenzocaliendo/Data_and_Codes_CP.zip
CP_counterfactuals.m
results_counterfactualsCP.m

%%%%%%%%
%%Step 2: identify important variables
%%base year exports: xbilattau_exp
%%counterfactual with all tariff changes: xbilattau_all_exp
%%counterfactual with NAFTA only tariff changes: xbilattau_all_exp_oN

%%%%%%%%
%%Step 3: identify structure of CP data matrices
%%Column is source country, row is destination country
%%first 31x31 submatrix is for first tradable sector, second is for second tradable sector.  20 tradable sectors, 20 non-tradable sectors.  
%%mexico is country 20, canada is country 5, usa is country 30
sectors =[' Agriculture    ';' Mining         ';' Food           ';' Textile        ';
' Wood           ';' Paper          ';' Petroleum      ';' Chemicals      ';
' Plastic        ';' Minerals       ';' Basic metals   ';' Metal products ';
' Machinery nec  ';' Office         ';' Electrical     ';' Com            ';
' Medical        ';' Auto           ';' Other Transport';' Other          ';
];

countries = ['Argentina    ';'Australia    ';'Austria      ';
'Brazil       ';'Canada       ';'Chile        ';'China        ';
'Denmark      ';'Finland      ';'France       ';'Germany      ';
'Greece       ';'Hungary      ';'India        ';'Indonesia    ';
'Ireland      ';'Italy        ';'Japan        ';'Korea        ';
'Mexico       ';'Netherlands  ';'New Zealand  ';'Norway       ';
'Portugal     ';'SouthAfrica  ';'Spain        ';'Sweden       ';
'Turkey       ';'UK           ';'USA          ';'ROW          ';
];


%%NAFTA bilateral trade growth
%%Column is source country, row is destination country
%%row is first number then column
%rows are (0:[length sectors-1])*[number countries]+[country number]
%20 sectors, 31 countries
mex_row = ((0:39).*31)+(20)
usa_row = ((0:39).*31)+(30)
can_row = ((0:39).*31)+(5)
mex_col = 20
usa_col = 30
can_col = 5

%%%%%%%%
%%Step 4: Compute growth
%%Now compute growth
export_growth = 100*(log(xbilattau_all_exp)-log(xbilattau_exp));

%%Column is source country, row is destination country
export_growth_mex_can = export_growth(can_row,mex_col);
export_growth_usa_can = export_growth(can_row,usa_col);
export_growth_can_mex = export_growth(mex_row,can_col);
export_growth_usa_mex = export_growth(mex_row,usa_col);
export_growth_can_usa = export_growth(usa_row,can_col);
export_growth_mex_usa = export_growth(usa_row,mex_col);

NAFTA_growth = [export_growth_can_mex export_growth_can_usa export_growth_mex_can export_growth_mex_usa export_growth_usa_can export_growth_usa_mex]
NAFTA_headers = {'mex_can' 'usa_can' 'can_mex' 'usa_mex' 'can_usa' 'mex_usa'};

NAFTA_dataset = dataset({NAFTA_growth(1:20,:),NAFTA_headers{:}})

%%%%%%%%
%%Step 5: Save Results
%%Export dataset as a csv file
export(NAFTA_dataset,'File','CP_NAFTA_Output.csv','Delimiter',',')



%%%%%%%%
%%Step 6: Reapeat previous two steps for NAFTA TARIFF CHANGES ONLY
%%%
export_growth_oN = 100*(log(xbilattau_all_exp_oN)-log(xbilattau_exp));

export_growth_oN_mex_can = export_growth_oN(can_row,mex_col);
export_growth_oN_usa_can = export_growth_oN(can_row,usa_col);
export_growth_oN_can_mex = export_growth_oN(mex_row,can_col);
export_growth_oN_usa_mex = export_growth_oN(mex_row,usa_col);
export_growth_oN_can_usa = export_growth_oN(usa_row,can_col);
export_growth_oN_mex_usa = export_growth_oN(usa_row,mex_col);

NAFTA_headers = {'mex_can' 'usa_can' 'can_mex' 'usa_mex' 'can_usa' 'mex_usa'};
NAFTA_oN_growth = [export_growth_oN_can_mex export_growth_oN_can_usa export_growth_oN_mex_can export_growth_oN_mex_usa export_growth_oN_usa_can export_growth_oN_usa_mex]

NAFTA_oN_dataset = dataset({NAFTA_oN_growth(1:20,:),NAFTA_headers{:}})

export(NAFTA_oN_dataset,'File','CP_NAFTA_oN_Output.csv','Delimiter',',')